# Generated by roxygen2: do not edit by hand

S3method(print,google_font)
S3method(print,xaringanthemer_default)
export(apply_alpha)
export(choose_dark_or_light)
export(darken_color)
export(duo)
export(duo_accent)
export(duo_accent_inverse)
export(google_font)
export(google_language_codes)
export(lighten_color)
export(mono_accent)
export(mono_accent_inverse)
export(mono_dark)
export(mono_light)
export(scale_xaringan_color_continuous)
export(scale_xaringan_color_discrete)
export(scale_xaringan_colour_continuous)
export(scale_xaringan_colour_discrete)
export(scale_xaringan_continuous)
export(scale_xaringan_discrete)
export(scale_xaringan_fill_continuous)
export(scale_xaringan_fill_discrete)
export(solarized_dark)
export(solarized_light)
export(style_duo)
export(style_duo_accent)
export(style_duo_accent_inverse)
export(style_extra_css)
export(style_mono_accent)
export(style_mono_accent_inverse)
export(style_mono_dark)
export(style_mono_light)
export(style_solarized_dark)
export(style_solarized_light)
export(style_xaringan)
export(theme_xaringan)
export(theme_xaringan_base)
export(theme_xaringan_get_value)
export(theme_xaringan_inverse)
export(theme_xaringan_restore_defaults)
export(theme_xaringan_set_defaults)
export(write_extra_css)
export(write_xaringan_theme)
export(xaringanthemer_font_default)
importFrom(grDevices,col2rgb)
importFrom(grDevices,hsv)
importFrom(grDevices,rgb)
importFrom(grDevices,rgb2hsv)
